use argh::FromArgs;

use crate::action::ActionExec;
use crate::api::qbittorrent::ApiClient;
use crate::config::Config;
use crate::error::Error;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "get")]
/// get info about a specific torrent on qBittorrent
pub struct GetAction {
    #[argh(switch)]
    /// the positional argument is a magnet link, not an infohash
    magnet: bool,
    #[argh(switch, short = 'j')]
    /// return parsed JSON response from API
    json: bool,
    #[argh(positional)]
    /// the infohash (or magnet link with --magnet) to retrieve
    torrent: String,
}

impl ActionExec for GetAction {
    fn exec(&self, config: &Config) -> Result<(), Error> {
        let api = ApiClient::from_config(&config)?;
        if let Some(t) = api.get(&self.torrent)? {
            if self.json {
                println!("{}", &serde_json::to_string(&t).unwrap());
            } else {
                println!("{}", t.hash);
            }
        }

        Ok(())
    }
}
