use snafu::prelude::*;
use qbittorrent_web_api::Api;

use crate::error::{Error, InternalApiSnafu as ApiError};

#[derive(Debug)]
pub struct RawAsyncApiClient {
    pub api: qbittorrent_web_api::api_impl::Authenticated,
}

impl RawAsyncApiClient {
    pub async fn login(host: &str, login: &str, password: &str) -> Result<RawAsyncApiClient, Error> {
        Ok(RawAsyncApiClient {
            api: Api::login(host, login, password).await.context(ApiError)?,
        })
    }

    #[allow(dead_code)]
    pub async fn add(&self, magnet: &str, paused: bool) -> Result<String, Error> {
        if paused {
            self.api.torrent_management().add(magnet).paused("true").send_raw().await.context(ApiError)
        } else {
            self.api.torrent_management().add(magnet).send_raw().await.context(ApiError)
        }
    }

    #[allow(dead_code)]
    pub async fn get(&self, hash: &str) -> Result<String, Error> {
        self.api.torrent_management().properties_raw(hash).await.context(ApiError)
    }

    #[allow(dead_code)]
    pub async fn list(&self) -> Result<String, Error> {
        self.api.torrent_management().info().send_raw().await.context(ApiError)
    }

    #[allow(dead_code)]
    pub async fn add_tracker(&self, hash: &str, url: &str) -> Result<String, Error> {
        self.api.torrent_management().add_trackers_raw(hash, url).await.context(ApiError)
    }

    #[allow(dead_code)]
    pub async fn get_trackers(&self, hash: &str) -> Result<String, Error> {
        self.api.torrent_management().trackers_raw(hash).await.context(ApiError)
    }

    #[allow(dead_code)]
    pub async fn remove_tracker(&self, hash: &str, url: &str) -> Result<String, Error> {
        self.api.torrent_management().remove_trackers_raw(hash, &vec!(url)).await.context(ApiError)
    }
}
