use argh::FromArgValue;

use crate::Error;
use crate::api::qbittorrent::ApiClient;

#[derive(Debug)]
pub enum TorrentTarget {
    All,
    Hash(String),
}

impl TorrentTarget {
    // TODO: replace ApiClient here with a trait so it can be cleanly separated even with async API, or transmission APi
    pub fn to_vec(&self, api: &ApiClient) -> Result<Vec<String>, Error> {
        match self {
            TorrentTarget::All => {
                Ok(api.list()?.into_iter().map(|t| t.hash.clone()).collect())
            }, TorrentTarget::Hash(s) => {
                Ok(vec!(s.clone()))
            }
        }
    }
}

impl FromArgValue for TorrentTarget {
    fn from_arg_value(value: &str) -> Result<Self, String> {
        if value == "all" {
            Ok(TorrentTarget::All)
        } else {
            Ok(TorrentTarget::Hash(value.to_string()))
        }
    }
}
