#[macro_use] extern crate serde;
use snafu::prelude::*;

mod action;
mod api;
pub use api::{Torrent, TorrentList, IntoTorrent};
mod config;
use config::Config;
mod cli;
use cli::Cli;
mod error;
use crate::error::{Error, ConfigSnafu as ConfigError};
mod utils;

fn fallible_main() -> Result<(), Error> {
    let cli = Cli::from_args();
    let config = Config::from_cli(&cli).context(ConfigError)?;
    // TODO: Make ActionExec type return Option<String>? where None means no data was found and so we abort with a proper exit code
    cli.command.exec(&config)?;

    Ok(())
}

fn main() {
    let res = fallible_main();
    if res.is_err() {
        let err = res.unwrap_err();
        eprintln!("{}", err);
        std::process::exit(1);
    }
}
